%% Experiment 04: Number vs. Volume distributions
% Statistical Analysis

%% Loading features into Matlab
%  Features were extracted by ImageJ an located into a 'txt' file

clear, clc, close all;

%load objects' features extracted by ImageJ
feat = importdata('ex04.txt');
area = feat.data(:,2);
perim = feat.data(:,3);
circ = feat.data(:,4);
maxf = feat.data(:,5); % max Feret's diameter
angf = feat.data(:,8); % Feret's angle
minf = feat.data(:,9); % min Feret's diameter
asrat = feat.data(:,10);
rndness = feat.data(:,11);
solid = feat.data(:,12);

%% Particle Number Weighted Distributions

% particle size (diameter) distribution
% we use the maximum Feret as the particle diameter
[n, x] = hist(maxf, 10);
figure('Name','PSD (number weighthed)', 'NumberTitle','off');
bar(x, n/(sum(n)/2)), xlabel('diameter (mm)'), ylabel('relative % in class');

% ronudness analysis
% we use an dimensionless parameter to account for the number of particles
% roundness of 1 are spheres, roundness of 1/2 are ellipsoids
[n, x] = hist(rndness, 7);
figure('Name','PSD (number weighthed)', 'NumberTitle','off');
bar(x, n/(sum(n))), xlabel('roundness'), ylabel('relative %');
title('PSD (number weighthed)');
axis([0.4 1.1 0 .6]);

% statistical values for roundness (by particle kind)
eind = find(rndness < x(2));    % ellipsoids are located below the 2nd bin
sind = find(rndness > x(6));    % spheres are located above the 6th bin
emn = mean(rndness(eind));      % mean for the elliptical objects
estd = std(rndness(eind));      % standard deviation for the elliptical objects
smn = mean(rndness(sind));      % mean for the spherical objects
sstd = std(rndness(sind));      % standard deviation for the spherical objects

% other features
figure('Name','PSD (number weighthed)', 'NumberTitle','off');
subplot(1,3,1), hist(area, 100), xlabel('area (mm^2)'), ylabel('objects');
subplot(1,3,2), hist(perim, 100); xlabel('perimeter (mm)');
subplot(1,3,3), hist(asrat, 100); xlabel('aspect ratio');
%subplot(2,3,4), hist(circ, 100); xlabel('shape factor');
%subplot(2,3,5), hist(maxf, 100), xlabel('max Feret'), ylabel('objects');
%subplot(2,3,6), hist(minf, 100), xlabel('min Feret');

%scatter plots
c = corr(area, perim);
figure('Name','Scatter plot', 'NumberTitle','off');
scatter(area, perim, '.b');
title(['correlation = ' num2str(c)]);
xlabel('area (mm^2)'), ylabel('perimetre (mm)');

figure('Name','Scatter plot', 'NumberTitle','off');
scatter(area, asrat, '.b');
xlabel('area (mm^2)'), ylabel('aspect ratio');

figure('Name','Scatter plot', 'NumberTitle','off');
scatter(perim, asrat, '.b');
xlabel('perimetre (mm)'), ylabel('aspect ratio');

figure('Name','Scatter plot', 'NumberTitle','off');
scatter3(area, perim, asrat, '.b');
xlabel('area (mm^2)'), ylabel('perimetre (mm)'), zlabel('aspect ratio');

%% Particle Volume Weighted Distributions

% CLASS1: spheres
% v_sph = 4/3 * pi * rad^3; (where rad = max_feret/2)
i1 = find(rndness == 1);                % finding spherical particles
v1 = 4/3 * pi * power(maxf(i1)/2, 3);   % volume just for the spherical
[n1, x1] = hist(maxf(i1), 10);          % bins for the spherical based on diameter

% CLASS2: ellipsoids
% v_ell = 4/3 * pi *(a * b * c); (where a = max_feret/2; b,c = min_feret/2)
i2 = find(rndness < 0.9);               % finding elliptical particles
v2 = 4/3 * pi * (maxf(i2)/2).*power(minf(i2)/2, 2);    % volume just for the elliptical
[n2, x2] = hist(maxf(i2), 10);          % bins for the elliptical based on diameter

figure('Name','PSD (volume weighthed)', 'NumberTitle','off'), hold on;
bar(x1, (n1.*(4/3 * pi * power(x1./2, 3)))/(sum(v1)+sum(v2)));
% for ellipsoids, we supose a minor semi-axe about 0,25 mm (10 pixels)
bar(x2, (n2.*(4/3 * pi * (x2./2).*.25^2)/(sum(v1)+sum(v2))));
xlabel('diameter (mm)'), ylabel('relative %');
title('PSD (volume weighthed)');
